@@ -14,6 +14,7 @@ dat <- data.frame(
   Dat = as.Date("2018-05-01") + c(1, 1, 2, 2, 3, 4, 5, 6, 3, 4),
   stringsAsFactors = FALSE
 )
+dat$s <- selectall(a = c(1, 1, 0, 0, 0, 1, 0, 1, 0, 0), b = c(0, 0, 1, 1, 1, 0, 1, 0, 1, 1))
 dat2 <- dat
 
 ###########################################################################################################
@@ -25,7 +26,7 @@ for(i in 1:3)
   if(i == 2) dat$id <- as.character(dat$id) else if(i == 3) dat$id <- as.factor(dat$id)
   test_that(paste0("Basic paired call; class(id) = ", class(dat$id), "; na.paired('asis')"), {
     expect_identical(
-      capture.kable(summary(paired(tp ~ Cat + Fac + Num + Ord + Lgl + Dat, data = dat, id = id,
+      capture.kable(summary(paired(tp ~ Cat + Fac + Num + Ord + Lgl + Dat + s, data = dat, id = id,
                                    signed.rank.exact = FALSE, na.action = na.paired("asis")), text = TRUE)),
       c("|             |         1 (N=5)         |         2 (N=5)         | Difference (N=4) | p value|",
         "|:------------|:-----------------------:|:-----------------------:|:----------------:|-------:|",
@@ -50,7 +51,10 @@ for(i in 1:3)
         "|-  TRUE      |        2 (40.0%)        |        3 (60.0%)        |    1 (50.0%)     |        |",
         "|Dat          |                         |                         |                  |   0.182|",
         "|-  Median    |       2018-05-04        |       2018-05-05        |      0.500       |        |",
-        "|-  Range     | 2018-05-02 - 2018-05-06 | 2018-05-02 - 2018-05-07 |  0.000 - 1.000   |        |"
+        "|-  Range     | 2018-05-02 - 2018-05-06 | 2018-05-02 - 2018-05-07 |  0.000 - 1.000   |        |",
+        "|s            |                         |                         |                  |        |",
+        "|-  a         |        1 (20.0%)        |        3 (60.0%)        |    2 (50.0%)     |        |",
+        "|-  b         |        4 (80.0%)        |        2 (40.0%)        |    2 (50.0%)     |        |"
       )
     )
   })
@@ -279,4 +283,22 @@ test_that("12/27/2019: informative error when no stats are computed (#273)", {
   expect_error(summary(paired(tp ~ Cat, data = dat2, id = id, cat.stats = "Nmiss")), "Nothing to show for variable")
 })
 
+test_that("NAs in sign.test, plus Nsigntest (#326)", {
+  d <- data.frame(
+    tp = rep(c("Time 1", "Time 2"), times = 4),
+    id = c(1, 1, 2, 2, 3, 3, 4, 4),
+    a = c(1, 2, 2, 3, 3, 4, 5, NA)
+  )
+  expect_identical(
+    capture.kable(summary(paired(tp ~ sign.test(a), id = id, data = d, numeric.stats = c("Nmiss", "meansd", "range", "Nsigntest")), text = TRUE)),
+    c("|                 | Time 1 (N=4)  | Time 2 (N=4)  | Difference (N=4) | p value|",
+      "|:----------------|:-------------:|:-------------:|:----------------:|-------:|",
+      "|a                |               |               |                  |   0.250|",
+      "|-  N-Miss        |       0       |       1       |        1         |        |",
+      "|-  Mean (SD)     | 2.750 (1.708) | 3.000 (1.000) |  1.000 (0.000)   |        |",
+      "|-  Range         | 1.000 - 5.000 | 2.000 - 4.000 |  1.000 - 1.000   |        |",
+      "|-  N (sign test) |      NA       |      NA       |        3         |        |"
+    )
+  )
+})
 
